@@ -6,6 +6,6 @@
 #ifndef _INC_LUKS_XTS_H
 #define _INC_LUKS_XTS_H
 
-DECLSPEC void xts_mul2 (u32 *in, u32 *out);
+DECLSPEC void xts_mul2 (PRIVATE_AS u32 *in, PRIVATE_AS u32 *out);
 
 #endif // _INC_LUKS_XTS_H
